@@ -104,6 +104,25 @@ class Ensemble(APIResource):
         cls.__cleanup_report(result)
         return WhatifyResponse(data=result)
 
+    @classmethod
+    def get_feature_importance_report(cls, id: int, api_key: str = None) -> WhatifyResponse:
+        """
+        Gets feature importance report for Ensemble.
+
+        Args:
+            id (int): Ensemble ID.
+            api_key (Optional[str]): Explicit api_key, not required if `fireflyai.authenticate` was run prior.
+
+        Returns:
+            WhatifyResponse: Contains mapping of feature importance for the ensemble_id.
+        """
+        requestor = APIRequestor()
+        url = "reports/{prefix}/{id}/feature_importance".format(prefix=cls._CLASS_PREFIX, id=id)
+        response = requestor.get(url=url, api_key=api_key)
+        result = response.to_dict()
+        cls.__cleanup_report(result)
+        return WhatifyResponse(data=result)
+
     @classmethod
     def set_ensemble_in_production(cls, ensemble_id: int, api_key: str = None) -> WhatifyResponse:
         """
@@ -256,3 +275,20 @@ class Ensemble(APIResource):
     def get_ensemble_id(cls, task_id) -> WhatifyResponse:
         ensemble_id = cls.list(filter_={'task_id': [task_id], 'stage': ['TASK', 'REFIT']})['hits'][-1]['id']
         return ensemble_id
+
+    @classmethod
+    def run_model_sensitivity(cls, ensemble_id: int, api_key: str = None) -> WhatifyResponse:
+        """
+        run the model sensitivity for Ensemble
+
+        Args:
+            id (int): ensemble ID.
+            api_key (Optional[str]): Explicit `api_key`, not required, if `Whatify.login()` was run prior.
+
+        Returns:
+            WhatifyResponse: Contains status of the trigger.
+        """
+        requestor = APIRequestor()
+        url = '{prefix}/{ensemble_id}/sensitivity'.format(prefix=cls._CLASS_PREFIX, ensemble_id=ensemble_id)
+        response = requestor.post(url, api_key=api_key)
+        return response
