@@ -55,6 +55,24 @@ class Wisdom(APIResource):
             response = [d for d in response if str(d['name']).find(search_term) != -1]
         return response
 
+    @classmethod
+    def get_suggest_wisdom_list(cls, search_term: str = None, api_key: str = None) -> WhatifyResponse:
+        """
+        Gets the suggest wisdoms list for the user can filter with search_term.
+
+        Args:
+            api_key (Optional[str]): Explicit `api_key`, not required, if `Whatify.login()` was run prior.
+            search_term (Optional[str]): the search term you want to filter
+        :return:
+            WhatifyResponse: Contains mapping of suggest wisdoms for the user.
+        """
+        requestor = APIRequestor()
+        url = 'suggestions'
+        response = requestor.get(url, api_key=api_key)['result']
+        if search_term:
+            response = [d for d in response if str(d['name']).find(search_term) != -1]
+        return response
+
     @classmethod
     def get_wisdom(cls, id: int, api_key: str = None) -> WhatifyResponse:
         """
