@@ -172,7 +172,7 @@ class MyWhatify:
         try:
             retval = cls.magento_api(api_method='GET', table=table, onlytotal=True, get_df=False)['data']['total']
         except Exception as ex:
-            logging.info('Failed to get table count, got error: ' + str(ex))
+            logging.info('Failed to get table count') #, got error: ' + str(ex))
         return retval
 
     @classmethod
@@ -200,12 +200,12 @@ class MyWhatify:
         try:
             retval = cls.base_api(url=base_url, method=api_method, headers=cls.magento_headers, body=body)
         except Exception as e:
-            logging.info('Failed to get data from api, got error: ' + str(e))
+            logging.info('Failed to get data from api') #, got error: ' + str(e))
         if retval and get_df:
             try:
                 retval = pd.DataFrame.from_dict(retval['data']['rows'], orient='columns')
             except Exception as ex:
-                logging.info('Failed to convert data into DataFrame, got error: ' + str(ex))
+                logging.info('Failed to convert data into DataFrame') #, got error: ' + str(ex))
         return retval
 
     #############################
